@@ -236,13 +236,13 @@ impl Command {
         self
     }
 
-    pub fn success_log_level(&mut self, level: LogLevel) -> &mut Command {
-        self.success_log_level = level;
+    pub fn success_log_level(&mut self, level_filter: log::LevelFilter) -> &mut Command {
+        self.success_log_level = LogLevel::new(level_filter);
         self
     }
 
-    pub fn fail_log_level(&mut self, level: LogLevel) -> &mut Command {
-        self.fail_log_level = level;
+    pub fn fail_log_level(&mut self, level_filter: log::LevelFilter) -> &mut Command {
+        self.fail_log_level = LogLevel::new(level_filter);
         self
     }
 
