@@ -20,6 +20,17 @@ impl LogLevel {
             log::LevelFilter::Trace => LogLevel::Trace,
         }
     }
+
+    pub fn level_filter(&self) -> log::LevelFilter {
+        match self {
+            LogLevel::Off => log::LevelFilter::Off,
+            LogLevel::Error => log::LevelFilter::Error,
+            LogLevel::Warn => log::LevelFilter::Warn,
+            LogLevel::Info => log::LevelFilter::Info,
+            LogLevel::Debug => log::LevelFilter::Debug,
+            LogLevel::Trace => log::LevelFilter::Trace,
+        }
+    }
 }
 impl Default for LogLevel {
     fn default() -> Self {
